==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d9/d15/strings_8cpp.js <==
var strings_8cpp =
[
    [ "LanguagePack", "df/dfc/structLanguagePack.html", "df/dfc/structLanguagePack" ],
    [ "UnitConversion", "dc/d39/structUnitConversion.html", "dc/d39/structUnitConversion" ],
    [ "Units", "de/dff/structUnits.html", "de/dff/structUnits" ],
    [ "UnitsLong", "d6/d7f/structUnitsLong.html", "d6/d7f/structUnitsLong" ],
    [ "LanguagePackGlyphSearcher", "da/dc0/classLanguagePackGlyphSearcher.html", "da/dc0/classLanguagePackGlyphSearcher" ],
    [ "CheckForMissingGlyphs", "d9/d15/strings_8cpp.html#a2e98bff498bb2e2b86925f501df4fa17", null ],
    [ "ConvertDisplaySpeedToKmhishSpeed", "d9/d15/strings_8cpp.html#a66c26517cbff8e8b33dc0633948ce45e", null ],
    [ "ConvertDisplaySpeedToSpeed", "d9/d15/strings_8cpp.html#aa81754ff32c08ace73f39b790cfa6916", null ],
    [ "ConvertKmhishSpeedToDisplaySpeed", "d9/d15/strings_8cpp.html#aa7dc54c5bebead2602e2ff18a9792a1d", null ],
    [ "ConvertSpeedToDisplaySpeed", "d9/d15/strings_8cpp.html#ab9f9f1f591dc304909a51539d0b6dde8", null ],
    [ "CopyInDParam", "d9/d15/strings_8cpp.html#ad04b1e89f111e434e1d79a7489ebdecd", null ],
    [ "CopyOutDParam", "d9/d15/strings_8cpp.html#a0760e488e037fa015788e7b56e25f926", null ],
    [ "CopyOutDParam", "d9/d15/strings_8cpp.html#aa436527019f66ad6a788589c864ecc05", null ],
    [ "DeterminePluralForm", "d9/d15/strings_8cpp.html#a5b584eabff94366784cafdbd08f8b6be", null ],
    [ "FormatBytes", "d9/d15/strings_8cpp.html#a6aa80ace5a07fe89b3a6510b8558b996", null ],
    [ "FormatCommaNumber", "d9/d15/strings_8cpp.html#a5d9df69b8d8db63e6d6481825cf6fc08", null ],
    [ "FormatGenericCurrency", "d9/d15/strings_8cpp.html#a4d6663c5e28bd7408954c365f24d1ac6", null ],
    [ "FormatHexNumber", "d9/d15/strings_8cpp.html#a2b2182263a2793867ddd5d464cad0b40", null ],
    [ "FormatMonthAndYear", "d9/d15/strings_8cpp.html#a748ce3ddb1ec90c674f99eb9be647548", null ],
    [ "FormatNoCommaNumber", "d9/d15/strings_8cpp.html#a188c4c4b1b8cd2c9e291d81a9a8811ae", null ],
    [ "FormatNumber", "d9/d15/strings_8cpp.html#ad421063fed55a9686b77d6afe4e98f13", null ],
    [ "FormatString", "d9/d15/strings_8cpp.html#a3bbd1addf1771be9b0c39e7b6cbaa890", null ],
    [ "FormatTinyOrISODate", "d9/d15/strings_8cpp.html#a815dfea66dc080ee811abe5692b4e3e8", null ],
    [ "FormatYmdString", "d9/d15/strings_8cpp.html#a1f8f5835337a8750da3b7e162b9056ac", null ],
    [ "FormatZerofillNumber", "d9/d15/strings_8cpp.html#a14ef45dafb57b4030c768e7febdde84b", null ],
    [ "GenAndCoName", "d9/d15/strings_8cpp.html#a3fe56d59f03fa6a17baad020a9c0bd90", null ],
    [ "GenPresidentName", "d9/d15/strings_8cpp.html#aa13e04d814bfaa61586996d9a30d61fa", null ],
    [ "GetCurrentLanguageIsoCode", "d9/d15/strings_8cpp.html#a9bb9daa2980694ef765bc0d68f639500", null ],
    [ "GetCurrentLocale", "d9/d15/strings_8cpp.html#abfa23ea9f6f48fa1bc9671ad42fe27bf", null ],
    [ "GetLanguage", "d9/d15/strings_8cpp.html#a5d93a5b690ee39456d058c553f8e52eb", null ],
    [ "GetLanguageFileHeader", "d9/d15/strings_8cpp.html#a2cb01be2ff9fff723265e5281f40e674", null ],
    [ "GetLanguageList", "d9/d15/strings_8cpp.html#a90763266fbc90929f31d01b3884ec243", null ],
    [ "GetSpecialNameString", "d9/d15/strings_8cpp.html#a8f818ca637bd741ec2079e2b4c709bcc", null ],
    [ "GetSpecialTownNameString", "d9/d15/strings_8cpp.html#a0c67b3175d54d095ccf0fe6349908a68", null ],
    [ "GetString", "d9/d15/strings_8cpp.html#abf8e5b73d5a3df27cce71d0d3002f1d1", null ],
    [ "GetStringPtr", "d9/d15/strings_8cpp.html#a5a9616895a101e9dff169a97443445ab", null ],
    [ "GetStringWithArgs", "d9/d15/strings_8cpp.html#a06645dc6a11946a02a5eccf5daaa863c", null ],
    [ "InitializeLanguagePacks", "d9/d15/strings_8cpp.html#a7873d07c16edd42664c7318e46bb02a6", null ],
    [ "InjectDParam", "d9/d15/strings_8cpp.html#a097ed328e882218208864c833cc439ed", null ],
    [ "ParseStringChoice", "d9/d15/strings_8cpp.html#a708f9b8d79c5c376d35bfc9fb29d423b", null ],
    [ "ReadLanguagePack", "d9/d15/strings_8cpp.html#ac1a2347db7241de6be1c971e299b31a0", null ],
    [ "SetDParamMaxDigits", "d9/d15/strings_8cpp.html#ac905c885d0fe384022dda2b374743a7b", null ],
    [ "SetDParamMaxValue", "d9/d15/strings_8cpp.html#aafbc32e46aba04accff6ee3f6a5f2903", null ],
    [ "SetDParamStr", "d9/d15/strings_8cpp.html#ae3f5a13d749df83e4422c9de059f2586", null ],
    [ "SortNetworkLanguages", "d9/d15/strings_8cpp.html#a098d766321d0f3da4756eb415cb4bdb2", null ],
    [ "StationGetSpecialString", "d9/d15/strings_8cpp.html#a252b720357c45d599c877a985ec116ef", null ],
    [ "StringIDSorter", "d9/d15/strings_8cpp.html#a9d7e7525f97148a7bd2c6946f4200636", null ],
    [ "_config_language_file", "d9/d15/strings_8cpp.html#ac462fee6d254b2f08862b471e967d989", null ],
    [ "_current_collator", "d9/d15/strings_8cpp.html#aa229bb6e3459591d83a4719106d28b62", null ],
    [ "_current_language", "d9/d15/strings_8cpp.html#a13f2bcd307ecac0290847ec1d3b813fe", null ],
    [ "_current_text_dir", "d9/d15/strings_8cpp.html#a9ac657d09b66103d655dc74e155ab77d", null ],
    [ "_global_string_params", "d9/d15/strings_8cpp.html#a49ebdc238bf8a1225454ddc9bc5a5c8c", null ],
    [ "_global_string_params_data", "d9/d15/strings_8cpp.html#a0cdac9ef766e47d2d229f773260c1547", null ],
    [ "_global_string_params_type", "d9/d15/strings_8cpp.html#a09e982787a0bbb418319330da623367f", null ],
    [ "_initial_name_letters", "d9/d15/strings_8cpp.html#ae678ac7ce002e2604a040ced03c2ebaf", null ],
    [ "_langpack", "d9/d15/strings_8cpp.html#a3ef61274b0ee2c645630c2f84db8da33", null ],
    [ "_langpack_offs", "d9/d15/strings_8cpp.html#aa00a0b5b939bfed0f5547dbab9dc9bf9", null ],
    [ "_langtab_num", "d9/d15/strings_8cpp.html#a92ea053e169b466d093967c457913683", null ],
    [ "_langtab_start", "d9/d15/strings_8cpp.html#a5f6377bd2e14ddd6bbaa2c90ff9e450c", null ],
    [ "_languages", "d9/d15/strings_8cpp.html#a0363a4b23796118b5911a11f67fd6a69", null ],
    [ "_scan_for_gender_data", "d9/d15/strings_8cpp.html#a56348b8ecb589ba8e46809b0ebbd65ce", null ],
    [ "_silly_company_names", "d9/d15/strings_8cpp.html#afb1816d73427d8e5377e15144830d428", null ],
    [ "_silly_surname_list", "d9/d15/strings_8cpp.html#afbd6a317e3167350be5582d1d7814ddb", null ],
    [ "_surname_list", "d9/d15/strings_8cpp.html#a44e4cbfa4a27aa1de4ed4955ce198872", null ],
    [ "_units_force", "d9/d15/strings_8cpp.html#a70e81df64a3015525ad8f7593604a14a", null ],
    [ "_units_height", "d9/d15/strings_8cpp.html#a11e5b131286f24be935e4804117a1d1f", null ],
    [ "_units_power", "d9/d15/strings_8cpp.html#a4284dd992b07ea1ac11ad3092c4ab97b", null ],
    [ "_units_velocity", "d9/d15/strings_8cpp.html#a80d3fb7b0b597aefc7d339d863486d94", null ],
    [ "_units_volume", "d9/d15/strings_8cpp.html#a57270c3a8123ae803b2c0b2c5717bbae", null ],
    [ "_units_weight", "d9/d15/strings_8cpp.html#a5e1d5157af7decb01ddf445166bb87da", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d9/d15/strings_8cpp.js <==
var strings_8cpp =
[
    [ "LanguagePack", "df/dfc/structLanguagePack.html", "df/dfc/structLanguagePack" ],
    [ "LoadedLanguagePack", "d2/d83/structLoadedLanguagePack.html", "d2/d83/structLoadedLanguagePack" ],
    [ "UnitConversion", "dc/d39/structUnitConversion.html", "dc/d39/structUnitConversion" ],
    [ "Units", "de/dff/structUnits.html", "de/dff/structUnits" ],
    [ "UnitsLong", "d6/d7f/structUnitsLong.html", "d6/d7f/structUnitsLong" ],
    [ "LanguagePackGlyphSearcher", "da/dc0/classLanguagePackGlyphSearcher.html", "da/dc0/classLanguagePackGlyphSearcher" ],
    [ "CheckForMissingGlyphs", "d9/d15/strings_8cpp.html#a2e98bff498bb2e2b86925f501df4fa17", null ],
    [ "ConvertDisplaySpeedToKmhishSpeed", "d9/d15/strings_8cpp.html#a66c26517cbff8e8b33dc0633948ce45e", null ],
    [ "ConvertDisplaySpeedToSpeed", "d9/d15/strings_8cpp.html#aa81754ff32c08ace73f39b790cfa6916", null ],
    [ "ConvertKmhishSpeedToDisplaySpeed", "d9/d15/strings_8cpp.html#aa7dc54c5bebead2602e2ff18a9792a1d", null ],
    [ "ConvertSpeedToDisplaySpeed", "d9/d15/strings_8cpp.html#ab9f9f1f591dc304909a51539d0b6dde8", null ],
    [ "CopyInDParam", "d9/d15/strings_8cpp.html#ad04b1e89f111e434e1d79a7489ebdecd", null ],
    [ "CopyOutDParam", "d9/d15/strings_8cpp.html#aa436527019f66ad6a788589c864ecc05", null ],
    [ "CopyOutDParam", "d9/d15/strings_8cpp.html#a0760e488e037fa015788e7b56e25f926", null ],
    [ "DeterminePluralForm", "d9/d15/strings_8cpp.html#a5b584eabff94366784cafdbd08f8b6be", null ],
    [ "FormatBytes", "d9/d15/strings_8cpp.html#a6aa80ace5a07fe89b3a6510b8558b996", null ],
    [ "FormatCommaNumber", "d9/d15/strings_8cpp.html#a5d9df69b8d8db63e6d6481825cf6fc08", null ],
    [ "FormatGenericCurrency", "d9/d15/strings_8cpp.html#a4d6663c5e28bd7408954c365f24d1ac6", null ],
    [ "FormatHexNumber", "d9/d15/strings_8cpp.html#a2b2182263a2793867ddd5d464cad0b40", null ],
    [ "FormatMonthAndYear", "d9/d15/strings_8cpp.html#a748ce3ddb1ec90c674f99eb9be647548", null ],
    [ "FormatNoCommaNumber", "d9/d15/strings_8cpp.html#a188c4c4b1b8cd2c9e291d81a9a8811ae", null ],
    [ "FormatNumber", "d9/d15/strings_8cpp.html#ad421063fed55a9686b77d6afe4e98f13", null ],
    [ "FormatString", "d9/d15/strings_8cpp.html#a3bbd1addf1771be9b0c39e7b6cbaa890", null ],
    [ "FormatTinyOrISODate", "d9/d15/strings_8cpp.html#a815dfea66dc080ee811abe5692b4e3e8", null ],
    [ "FormatYmdString", "d9/d15/strings_8cpp.html#a1f8f5835337a8750da3b7e162b9056ac", null ],
    [ "FormatZerofillNumber", "d9/d15/strings_8cpp.html#a14ef45dafb57b4030c768e7febdde84b", null ],
    [ "GenAndCoName", "d9/d15/strings_8cpp.html#a3fe56d59f03fa6a17baad020a9c0bd90", null ],
    [ "GenPresidentName", "d9/d15/strings_8cpp.html#aa13e04d814bfaa61586996d9a30d61fa", null ],
    [ "GetCurrentLanguageIsoCode", "d9/d15/strings_8cpp.html#a9bb9daa2980694ef765bc0d68f639500", null ],
    [ "GetCurrentLocale", "d9/d15/strings_8cpp.html#abfa23ea9f6f48fa1bc9671ad42fe27bf", null ],
    [ "GetLanguage", "d9/d15/strings_8cpp.html#a5d93a5b690ee39456d058c553f8e52eb", null ],
    [ "GetLanguageFileHeader", "d9/d15/strings_8cpp.html#a2cb01be2ff9fff723265e5281f40e674", null ],
    [ "GetLanguageList", "d9/d15/strings_8cpp.html#a90763266fbc90929f31d01b3884ec243", null ],
    [ "GetSpecialNameString", "d9/d15/strings_8cpp.html#a8f818ca637bd741ec2079e2b4c709bcc", null ],
    [ "GetSpecialTownNameString", "d9/d15/strings_8cpp.html#a0c67b3175d54d095ccf0fe6349908a68", null ],
    [ "GetString", "d9/d15/strings_8cpp.html#abf8e5b73d5a3df27cce71d0d3002f1d1", null ],
    [ "GetStringPtr", "d9/d15/strings_8cpp.html#a5a9616895a101e9dff169a97443445ab", null ],
    [ "GetStringWithArgs", "d9/d15/strings_8cpp.html#a06645dc6a11946a02a5eccf5daaa863c", null ],
    [ "InitializeLanguagePacks", "d9/d15/strings_8cpp.html#a7873d07c16edd42664c7318e46bb02a6", null ],
    [ "InjectDParam", "d9/d15/strings_8cpp.html#a097ed328e882218208864c833cc439ed", null ],
    [ "ParseStringChoice", "d9/d15/strings_8cpp.html#a708f9b8d79c5c376d35bfc9fb29d423b", null ],
    [ "ReadLanguagePack", "d9/d15/strings_8cpp.html#ac1a2347db7241de6be1c971e299b31a0", null ],
    [ "SetDParamMaxDigits", "d9/d15/strings_8cpp.html#ac905c885d0fe384022dda2b374743a7b", null ],
    [ "SetDParamMaxValue", "d9/d15/strings_8cpp.html#aafbc32e46aba04accff6ee3f6a5f2903", null ],
    [ "SetDParamStr", "d9/d15/strings_8cpp.html#ae3f5a13d749df83e4422c9de059f2586", null ],
    [ "SortNetworkLanguages", "d9/d15/strings_8cpp.html#a098d766321d0f3da4756eb415cb4bdb2", null ],
    [ "StationGetSpecialString", "d9/d15/strings_8cpp.html#a252b720357c45d599c877a985ec116ef", null ],
    [ "StringIDSorter", "d9/d15/strings_8cpp.html#ab2948f3d6c2eda9e1208f92239e2954d", null ],
    [ "_config_language_file", "d9/d15/strings_8cpp.html#a32d6c38633f6e9709dea572e3834ee62", null ],
    [ "_current_collator", "d9/d15/strings_8cpp.html#a687bed6b841fbdbb1c3f34d5b16040c3", null ],
    [ "_current_language", "d9/d15/strings_8cpp.html#a13f2bcd307ecac0290847ec1d3b813fe", null ],
    [ "_current_text_dir", "d9/d15/strings_8cpp.html#a9ac657d09b66103d655dc74e155ab77d", null ],
    [ "_global_string_params", "d9/d15/strings_8cpp.html#a49ebdc238bf8a1225454ddc9bc5a5c8c", null ],
    [ "_global_string_params_data", "d9/d15/strings_8cpp.html#a0cdac9ef766e47d2d229f773260c1547", null ],
    [ "_global_string_params_type", "d9/d15/strings_8cpp.html#a09e982787a0bbb418319330da623367f", null ],
    [ "_initial_name_letters", "d9/d15/strings_8cpp.html#ae678ac7ce002e2604a040ced03c2ebaf", null ],
    [ "_langpack", "d9/d15/strings_8cpp.html#a0f5a0d4ee54e6bda6bacb89529c05bea", null ],
    [ "_languages", "d9/d15/strings_8cpp.html#a0363a4b23796118b5911a11f67fd6a69", null ],
    [ "_scan_for_gender_data", "d9/d15/strings_8cpp.html#a56348b8ecb589ba8e46809b0ebbd65ce", null ],
    [ "_silly_company_names", "d9/d15/strings_8cpp.html#afb1816d73427d8e5377e15144830d428", null ],
    [ "_silly_surname_list", "d9/d15/strings_8cpp.html#afbd6a317e3167350be5582d1d7814ddb", null ],
    [ "_surname_list", "d9/d15/strings_8cpp.html#a44e4cbfa4a27aa1de4ed4955ce198872", null ],
    [ "_units_force", "d9/d15/strings_8cpp.html#a70e81df64a3015525ad8f7593604a14a", null ],
    [ "_units_height", "d9/d15/strings_8cpp.html#a11e5b131286f24be935e4804117a1d1f", null ],
    [ "_units_power", "d9/d15/strings_8cpp.html#a4284dd992b07ea1ac11ad3092c4ab97b", null ],
    [ "_units_velocity", "d9/d15/strings_8cpp.html#a80d3fb7b0b597aefc7d339d863486d94", null ],
    [ "_units_volume", "d9/d15/strings_8cpp.html#a57270c3a8123ae803b2c0b2c5717bbae", null ],
    [ "_units_weight", "d9/d15/strings_8cpp.html#a5e1d5157af7decb01ddf445166bb87da", null ]
];
